# == Class: foreman::params
#
# Some global Foreman parameters for laziness (usability).
#
# === Parameters
#
# [*admin_user*]
#   Type: String/Username
#   Default: 'admin'
#
#   The admin user. Used to connect to the REST API and for web logins.
#
# [*admin_pass*]
#   Type: String
#   Default: Randomly generated by passgen
#
#   The password for the admin user, used to log into the Foreman web
#   UI.
#
# [*server*]
#   Type: Hostname/String
#   Default: <fqdn_puppetmasteer>
#
#   The server that the Foreman will run on.
#
# === Variables
#
# [*fqdn*]
#   Used to set the VirtualHost ServerName variable in the Apache conf file.
#
# === Authors
#
# Kendall Moore <kmoore@keywcorp.com>
#
class foreman::params {
  case $::osfamily {
    'RedHat': {
    }
    default: {
      fail("${::operatingsystem} not supported")
    }
  }
  $admin_user      = 'admin'
  $admin_password  = passgen('foreman_admin')
  $log_level       = 'WARN'
  $server          = $::fqdn
}
